# `loadable(LoaderComponent): (ContentComponent, text?) => LoadableContentComponent`

High order component factory that wraps your content component with supplied loader and pass prop `showLoader`
just to the loader

### Arguments
1. `LoaderComponent`: React component showing loader that receives:
    1. Prop `show` determining if loader should be visible.
    2. Prop `children` containing loadable content.
    3. Optionally `text` prop if provided into loadable.

### Returns
Function that receives 1-2 arguments and return content component wrapped with loader
1. `ContentComponent` (boolean): React component containing content that is loadable - hidden behind loader until load finish.
2. `text` (string [optional]): Text that is forwarded into `LoaderComponent`. Useful for different loading texts used for different contents.

### Examples

```jsx
import loadableFactory from 'ackee-frontend-toolkit/lib/HOC/loadable';

const SimpleLoader = ({ children, show, text }) => (
    <div>
        {children}
        {
            show && (
                <div style={{ position: 'absolute', top: 0, right: 0, bottom: 0, left: 0, background: 'grey' }}>
                    {text}
                </div>
            )
        }
    </div>
);

const loadable = loadableFactory(SimpleLoader);

const LoadableMain = loadable(MainPage);
const LoadableOther = loadable(OtherPage, 'Loading other page...');

<LoadableMain showLoader={true} />
<LoadableOther showLoader={false} />
```
