# `pure(equalityChecker): (UnpureComponent) => PureComponent`

Makre provided component pure - it means that component not rerender until it's props change. 

### Arguments
1. `equalityChecker` (function(prevProps, nextProps):bool [optional]) - Function that returns boolean which determines if prev props are equal to next props. You can provide your own eqaulity checker, if you don't provide equality checker, lodash's `isEqual` function is used.

### Returns
Function that accepts `UnpureComponent` (React component that should be optimilized for useless rerenderes) and return `PureComponent` (component that rerender only if their props change). Change is determined either by equality checker.

### Examples

```jsx
import pure from 'ackee-frontend-toolkit/lib/HOC/pure';

// 1. custom equality checker
const customEqualityChecker = (props, nextProps) => {
    return props.data.changableProp === nextProps.data.changableProp;
};

pure(customEqualityChecker)(props => (
    <div>
        { JSON.stringify(props.data, null, 2) }
    </div>
));

// 2. default equality checker
pure()(props => (
    <div>
        { JSON.stringify(props.data, null, 2) }
    </div>
));

```
