# Form actions

Actions related to [form saga](../sagas/form.md).

## `submitForm(formId: string, submitActionCreator: () => object): function`

### Arguments
1. `formId` Form unique identificator
2. `submitActionCreator` Action creator for form specific submit action 

### Returns
Form submit handler that is used for `handleSubmit` prop of `redux-form` `Form`.

### Examples

```js
import { connect } from 'react-redux';
import { bindActionCreators, compose } from 'redux';

import UserForm from './components/UserForm';

const createUserAction = () => ({
    type: 'CREATE_USER'
})

const formId = 'createUserForm';

export default compose(
    connect(
        (state) => ({
            initialValues: {
            },
        }),
        dispatch => ({
            onSubmit: bindActionCreators(
                formActions.submitForm(formId, createUserAction),
                dispatch,
            ),
        }),
    ),
    reduxForm({
        form: formId,
    }),
)(UserForm);
```

