# auth helpers

Simple helpers for working with authentication tokens.

### `setTokens(tokens: Tokens): void`
Save tokens into storage. `Tokens` can be any valid JS object.

### `getTokens(): Tokens`
Return tokens previously stored in storage.

### `clearTokens(): void`
Delete previously stored tokens.

### `updateTokens(tokens: Tokens): void`
Unlike `setTokens` method, it updates just received tokens (by key) and other left
untouched. If received token is not present in storage, it's added.

#### Examples

```js
import * as tokens from 'ackee-frontend-toolkit/lib/helpers/auth';

tokens.setTokens({
    accessToken: { 
        id: 6095, 
        token: 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9',
        expiration: '2017-12-11T15:15:35.000Z',
    },
    firebaseToken: {
        id: 1234,
        token: 'NTUyLCJleHAiOjE1MjI3NTAxNTIsImF1ZCI6Imh',
        expiration: '2017-12-11T17:30:00.000Z'
    }
});

tokens.getTokens();
/* 
 * {
 *   accessToken: { 
 *       id: 6095, 
 *       token: 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9',
 *       expiration: '2017-12-11T15:15:35.000Z',
 *   },
 *   firebaseToken: {
 *       id: 1234,
 *       token: 'NTUyLCJleHAiOjE1MjI3NTAxNTIsImF1ZCI6Imh',
 *       expiration: '2017-12-11T17:30:00.000Z'
 *   }
 * }
 */

tokens.updateTokens({
    firebaseToken: {
        id: 7890,
        token: 'Y29tL2dvb2dsZS5pZGVudGl0eS5pZGVudGl0eXR',
        expiration: '2017-12-11T17:30:00.000Z'
    }
});

tokens.getTokens();
/* 
 * {
 *   accessToken: { 
 *       id: 6095, 
 *       token: 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9',
 *       expiration: '2017-12-11T15:15:35.000Z',
 *   },
 *   firebaseToken: {
 *       id: 7890,
 *       token: 'Y29tL2dvb2dsZS5pZGVudGl0eS5pZGVudGl0eXR',
 *       expiration: '2017-12-11T17:30:00.000Z'
 *   }
 * }
 */

tokens.clearTokens();

tokens.getTokens();
/*
 * null
 */
```
