import React from 'react';
import { IntlProvider, intlShape } from 'react-intl';
import { Provider } from 'react-redux';
import configureStore from 'redux-mock-store';
import { mount, shallow } from 'enzyme';

var mockStore = configureStore([]);

var state = void 0;
var intl = void 0;

export var init = function init() {
    var initialState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var messages = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    state = initialState;
    // Create the IntlProvider to retrieve context for wrapping around.
    var intlProvider = new IntlProvider({ locale: 'cs', messages: messages }, {});
    intl = intlProvider.getChildContext().intl;
};

/**
 * When using React-Intl `injectIntl` on components, props.intl is required.
 */
function nodeWithIntlProp(node) {
    return React.createElement(Provider, { store: mockStore(state) }, React.cloneElement(node, { intl: intl }));
}

export function shallowWithIntl(node) {
    var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        context = _ref.context;

    return shallow(nodeWithIntlProp(node), {
        context: Object.assign({}, context, { intl: intl })
    });
}

export function mountWithIntl(node) {
    var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        context = _ref2.context,
        childContextTypes = _ref2.childContextTypes;

    return mount(nodeWithIntlProp(node), {
        context: Object.assign({}, context, { intl: intl }),
        childContextTypes: Object.assign({}, { intl: intlShape }, childContextTypes)
    });
}