import 'babel-polyfill';
import React from 'react';
import PropTypes from 'prop-types';
import { Provider } from 'react-redux';
import { IntlProvider } from 'react-intl';
import _ from 'lodash';

import { storiesOf } from '@storybook/react';

import DataLoadDelay from './DataLoadDelay';
import { Conversations } from '../';

import { intlMessages } from './chatData';

import { store } from './chat.envSetup';

import './chatStories.scss';
import '../styles.scss';

var SearchIcon = function SearchIcon() {
    return React.createElement(
        'svg',
        {
            width: '18px',
            height: '18px',
            viewBox: '0 0 18 18',
            version: '1.1',
            xmlns: 'http://www.w3.org/2000/svg'
        },
        React.createElement(
            'g',
            {
                id: 'Symbols',
                stroke: 'none',
                strokeWidth: '1',
                fill: 'none',
                fillRule: 'evenodd'
            },
            React.createElement(
                'g',
                { id: 'ic_search_24px', transform: 'translate(-3.000000, -3.000000)' },
                React.createElement('path', {
                    d: 'M15.5,14 L14.71,14 L14.43,13.73 C15.41,12.59 16,11.11 16,9.5 C16,5.91 13.09,3 9.5,3 C5.91,3 3,5.91 3,9.5 C3,13.09 5.91,16 9.5,16 C11.11,16 12.59,15.41 13.73,14.43 L14,14.71 L14,15.5 L19,20.49 L20.49,19 L15.5,14 Z M9.5,14 C7.01,14 5,11.99 5,9.5 C5,7.01 7.01,5 9.5,5 C11.99,5 14,7.01 14,9.5 C14,11.99 11.99,14 9.5,14 Z',
                    id: 'Shape',
                    fill: '#9BC111',
                    fillRule: 'nonzero'
                }),
                React.createElement('polygon', { id: 'Shape', points: '0 0 24 0 24 24 0 24' })
            )
        )
    );
};

var ConversationsItem = function ConversationsItem(_ref) {
    var userId = _ref.userId,
        conversationId = _ref.conversationId,
        users = _ref.users;
    return React.createElement(
        'div',
        { className: 'content' },
        conversationId,
        ' ',
        _.get(_.find(users, function (__, id) {
            return id !== userId;
        }), 'name')
    );
};

ConversationsItem.propTypes = {
    userId: PropTypes.string.isRequired,
    conversationId: PropTypes.string.isRequired,
    users: PropTypes.objectOf(PropTypes.shape({
        name: PropTypes.string
    })).isRequired
};

storiesOf('Modules|chat/Conversations', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            IntlProvider,
            { locale: 'en', messages: intlMessages },
            React.createElement(
                'div',
                { className: 'panel conversations-list-panel' },
                story()
            )
        )
    );
}).add('basic', function () {
    return React.createElement(Conversations, {
        ConversationsItem: ConversationsItem,
        userId: 'dispatcher_9'
    });
}).add('no data', function () {
    return React.createElement(Conversations, { ConversationsItem: ConversationsItem, userId: 'dispatcher_8' });
}).add('default loader', function () {
    return React.createElement(
        DataLoadDelay,
        {
            store: store,
            firebaseDataPath: 'usersConversations/dispatcher_9'
        },
        React.createElement(Conversations, { ConversationsItem: ConversationsItem, userId: 'dispatcher_9' })
    );
}).add('custom loader', function () {
    return React.createElement(
        DataLoadDelay,
        {
            store: store,
            firebaseDataPath: 'usersConversations/dispatcher_9'
        },
        React.createElement(Conversations, {
            ConversationsItem: ConversationsItem,
            userId: 'dispatcher_9',
            loader: React.createElement(
                'h3',
                { style: { color: 'red', textAlign: 'center' } },
                'Loading conversations red...'
            )
        })
    );
}).add('custom no data message', function () {
    return React.createElement(Conversations, {
        ConversationsItem: ConversationsItem,
        userId: 'dispatcher_8',
        noDataMessage: React.createElement(
            'h4',
            null,
            'Sorry, no conversations available'
        )
    });
}).add('with search bar', function () {
    return React.createElement(Conversations, {
        ConversationsItem: ConversationsItem,
        userId: 'dispatcher_9',
        searchEnabled: true,
        searchLabel: React.createElement(SearchIcon, null)
    });
});