var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import 'babel-polyfill';
import React from 'react';
import PropTypes from 'prop-types';
import { Provider } from 'react-redux';
import { IntlProvider } from 'react-intl';

import { storiesOf } from '@storybook/react';

import { MessageForm } from '../';

import { intlMessages } from './chatData';

import { store } from './chat.envSetup';

import './chatStories.scss';
import '../styles.scss';

var UploadIcon = function UploadIcon() {
    return React.createElement(
        'svg',
        {
            version: '1.1',
            xmlns: 'http://www.w3.org/2000/svg',
            x: '0px',
            y: '0px',
            viewBox: '0 0 53.3 53.4'
        },
        React.createElement(
            'g',
            null,
            React.createElement('path', {
                d: 'M44.1,32.5c-0.6,0-1.2,0.5-1.2,1.2v8c0,0.1-0.1,0.1-0.2,0.1H10.6c-0.1,0-0.2-0.1-0.2-0.1v-8c0-0.6-0.5-1.2-1.2-1.2 C8.6,32.5,8,33,8,33.6v8c0,1.4,1.1,2.5,2.5,2.5h32.2c1.4,0,2.5-1.1,2.5-2.5v-8C45.3,33,44.7,32.5,44.1,32.5z'
            }),
            React.createElement('path', {
                d: 'M17.4,21.2l8-8v21c0,0.6,0.5,1.2,1.2,1.2c0.6,0,1.2-0.5,1.2-1.2v-21l8,8c0.2,0.2,0.5,0.3,0.8,0.3c0.3,0,0.6-0.1,0.8-0.3 c0.5-0.5,0.5-1.2,0-1.7l-10-10c-0.2-0.2-0.5-0.3-0.8-0.3c-0.3,0-0.6,0.1-0.8,0.3l-10,10c-0.5,0.5-0.5,1.2,0,1.7 C16.2,21.7,17,21.7,17.4,21.2z'
            })
        )
    );
};

var InputField = function InputField(_ref) {
    var label = _ref.label,
        id = _ref.id,
        input = _ref.input;
    return React.createElement(
        React.Fragment,
        null,
        label ? React.createElement(
            'label',
            { htmlFor: id },
            label
        ) : null,
        React.createElement('input', _extends({ id: id }, input))
    );
};

InputField.propTypes = {
    label: PropTypes.node.isRequired,
    id: PropTypes.string.isRequired,
    input: PropTypes.shape().isRequired
};

storiesOf('Modules|chat/MessageForm', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            IntlProvider,
            { locale: 'en', messages: intlMessages },
            React.createElement(
                'div',
                { className: 'panel messages-panel' },
                story()
            )
        )
    );
}).add('basic', function () {
    return React.createElement(MessageForm, {
        userId: 'dispatcher_9',
        conversationId: 'driver_1551',
        sendLabel: 'Send it!'
    });
}).add('custom input', function () {
    return React.createElement(MessageForm, {
        userId: 'dispatcher_9',
        conversationId: 'driver_1551',
        sendLabel: 'Send it!',
        newMessageInput: 'textarea'
    });
}).add('custom input properties', function () {
    return React.createElement(MessageForm, {
        userId: 'dispatcher_9',
        conversationId: 'driver_1551',
        sendLabel: 'Send it!',
        newMessageInput: InputField,
        newMessageInputProps: {
            label: 'FOOO',
            id: 'foo'
        }
    });
}).add('with sending files', function () {
    return React.createElement(MessageForm, {
        userId: 'dispatcher_9',
        conversationId: 'driver_1551',
        sendLabel: React.createElement(
            'strong',
            null,
            'Send it!'
        ),
        uploadLabel: React.createElement(
            'span',
            null,
            React.createElement(UploadIcon, null),
            'UPLOAD FILE..'
        ),
        filesEnabled: true
    });
});