"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.authorShape = undefined;

var _dependencies = require("../../dependencies");

var authorShape = exports.authorShape = _dependencies.PropTypes.shape({
    authorId: _dependencies.PropTypes.string.isRequired,
    name: _dependencies.PropTypes.string
});

var DefaultImageComponent = function DefaultImageComponent(_ref) {
    var image = _ref.image;
    return _dependencies.React.createElement(
        "a",
        { href: image, target: "_blank" },
        _dependencies.React.createElement("img", { src: image, alt: "" })
    );
};

DefaultImageComponent.propTypes = {
    image: _dependencies.PropTypes.string.isRequired
};

var DefaultAuthorComponent = function DefaultAuthorComponent(_ref2) {
    var author = _ref2.author,
        seen = _ref2.seen;
    return _dependencies.React.createElement(
        "span",
        null,
        author.name,
        " ",
        seen ? '' : '•'
    );
};

// We want also unused props in default to have definition of props
// for AuthorComponent complete
/* eslint-disable react/no-unused-prop-types */
DefaultAuthorComponent.propTypes = {
    author: authorShape.isRequired,
    seen: _dependencies.PropTypes.bool.isRequired,
    isMe: _dependencies.PropTypes.bool.isRequired
};
/* eslint-enable-line react/no-unused-prop-types */

DefaultAuthorComponent.defaultProps = {
    name: ''
};

var Message = function Message(_ref3) {
    var author = _ref3.author,
        image = _ref3.image,
        text = _ref3.text,
        time = _ref3.time,
        seen = _ref3.seen,
        dateFormat = _ref3.dateFormat,
        amIAuthor = _ref3.amIAuthor,
        MessageAuthor = _ref3.MessageAuthor,
        MessageImage = _ref3.MessageImage;

    var date = (0, _dependencies.moment)(time);

    var fullDateFormat = 'HH:mm';

    if ((0, _dependencies.moment)().diff(date, 'days') === 0) {
        fullDateFormat += " " + dateFormat;
    }

    return _dependencies.React.createElement(
        "div",
        {
            className: (0, _dependencies.classnames)('conversation__message', {
                'conversation__message--author-me': amIAuthor
            })
        },
        _dependencies.React.createElement(
            "div",
            { className: "conversation__message-inner" },
            _dependencies.React.createElement(
                "div",
                { className: "conversation__message-author" },
                _dependencies.React.createElement(MessageAuthor, {
                    author: author,
                    seen: seen,
                    isMe: amIAuthor
                })
            ),
            _dependencies.React.createElement(
                "div",
                { className: "conversation__message-bubble" },
                text && _dependencies.React.createElement(
                    "span",
                    { className: "conversation__message-text" },
                    text
                ),
                image && MessageImage,
                _dependencies.React.createElement(
                    "span",
                    { className: "conversation__message-date" },
                    date.format(fullDateFormat)
                )
            )
        )
    );
};

Message.propTypes = {
    author: authorShape,
    image: _dependencies.PropTypes.string,
    text: _dependencies.PropTypes.string,
    time: _dependencies.PropTypes.number.isRequired,
    seen: _dependencies.PropTypes.bool.isRequired,
    amIAuthor: _dependencies.PropTypes.bool.isRequired,

    MessageAuthor: _dependencies.PropTypes.func,
    MessageImage: _dependencies.PropTypes.func,
    dateFormat: _dependencies.PropTypes.string
};

Message.defaultProps = {
    author: {},
    image: null,
    text: null,

    MessageAuthor: DefaultAuthorComponent,
    MessageImage: DefaultImageComponent,
    dateFormat: 'DD MMM YYYY'
};

exports.default = (0, _dependencies.pure)()(Message);