'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.unseenSelector = exports.messagesSelector = exports.messagesCountsSelector = exports.conversationSelector = exports.isConversationLoadedSelector = exports.conversationsListSelector = exports.conversationsSearchValueSelector = exports.unseenConversationsSelector = exports.conversationsSelector = exports.userConversationsSelector = exports.isUserConversationsLoaded = exports.chatPagingSelector = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _dependencies = require('../../dependencies');

var _constants = require('../constants');

var _constants2 = _interopRequireDefault(_constants);

var _paths = require('../firebase/paths');

var paths = _interopRequireWildcard(_paths);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var userIdFromPropsSelector = function userIdFromPropsSelector(state, props) {
    return props.userId;
};
var conversationIdFromPropsSelector = function conversationIdFromPropsSelector(state, props) {
    return props.conversationId;
};

var chatPagingSelector = exports.chatPagingSelector = function chatPagingSelector(state) {
    return state.chat;
};

var firebaseUsersSelector = (0, _dependencies.createSelector)(_dependencies.firebaseSelector, function (firebase) {
    return (0, _dependencies._get)(firebase, 'data.' + paths.users().store, {});
});

/**
 * Conversations list
 */
var isUserConversationsLoaded = exports.isUserConversationsLoaded = (0, _dependencies.createSelector)(userIdFromPropsSelector, _dependencies.firebaseSelector, function (userId, firebase) {
    return !(0, _dependencies._get)(firebase, ['requesting', paths.userConversations(userId).id]);
});

var userConversationsSelector = exports.userConversationsSelector = (0, _dependencies.createSelector)(userIdFromPropsSelector, _dependencies.firebaseSelector, isUserConversationsLoaded, function (userId, firebase, isLoaded) {
    var userConversations = (0, _dependencies.populate)(firebase, paths.userConversations(userId).store, paths.populates.conversations);

    var activeUserConversations = (0, _dependencies._filter)(userConversations, function (userConversation) {
        return (0, _dependencies._has)(userConversation, 'conversation');
    }).map(function (userConversation) {
        var conversation = userConversation.conversation;


        return _extends({
            conversationId: (0, _dependencies._isString)(conversation) ? conversation : conversation.id
        }, userConversation);
    });

    return {
        isLoaded: isLoaded,
        conversations: activeUserConversations
    };
});

var hasUnseenMessages = function hasUnseenMessages(conversation) {
    return Boolean((0, _dependencies._get)(conversation, 'unseenMessagesCount', 0) > 0);
};

var isUnseenMoreRecent = function isUnseenMoreRecent(conversation) {
    return (0, _dependencies._get)(conversation, ['lastMessage', 'time'], 0);
};

var conversationsSelector = exports.conversationsSelector = (0, _dependencies.createSelector)(userConversationsSelector, _dependencies.firebaseSelector, function (userConversations, firebase) {
    var conversations = userConversations.conversations.map(function (_ref) {
        var conversationId = _ref.conversationId,
            unseenMessagesCount = _ref.unseenMessagesCount,
            conversation = _ref.conversation;
        return {
            conversationId: conversationId,
            lastMessage: (0, _dependencies._get)(conversation, 'lastMessage'),
            unseenMessagesCount: unseenMessagesCount,
            users: (0, _dependencies._get)(conversation, 'users')
        };
    });

    conversations = (0, _dependencies._orderBy)(conversations, [hasUnseenMessages, isUnseenMoreRecent], ['desc', 'desc']);

    var isEveryConversationLoaded = userConversations.conversations.every(function (_ref2) {
        var conversationId = _ref2.conversationId;

        return !(0, _dependencies._get)(firebase, ['requesting', paths.conversation(conversationId).id]);
    });

    return {
        isEmpty: conversations.legth === 0,
        isLoaded: userConversations.isLoaded && isEveryConversationLoaded,
        conversations: conversations
    };
});

var unseenConversationsSelector = exports.unseenConversationsSelector = (0, _dependencies.createSelector)(userConversationsSelector, function (userConversations) {
    return userConversations.conversations.filter(hasUnseenMessages);
});

var conversationsSearchFormSelector = (0, _dependencies.formValueSelector)(_constants2.default.SEARCH_CONVERSATION_FORM_ID);

var conversationsSearchValueSelector = exports.conversationsSearchValueSelector = function conversationsSearchValueSelector(state) {
    return conversationsSearchFormSelector(state, 'text');
};

var isConversationMatchedByFilter = function isConversationMatchedByFilter(_ref3, filterValue) {
    var user = _ref3.user;

    var userName = (0, _dependencies._get)(user, 'name');
    return (0, _dependencies._isString)(userName) && userName.toLowerCase().includes(filterValue.toLowerCase());
};

var conversationsListSelector = exports.conversationsListSelector = (0, _dependencies.createSelector)(conversationsSelector, firebaseUsersSelector, _dependencies.firebaseSelector, conversationsSearchValueSelector, function (_ref4, users, firebase, searchFormValue) {
    var conversations = _ref4.conversations,
        isLoaded = _ref4.isLoaded;

    var conversationsList = conversations.map(function (conversation) {
        var conversationId = conversation.conversationId;

        var conversationDetail = (0, _dependencies._get)(firebase, 'data.' + paths.conversation(conversationId).store, {});

        var conversationUsers = (0, _dependencies._get)(conversationDetail, 'users', {});

        return _extends({}, conversation, conversationDetail, {
            users: (0, _dependencies._mapValues)(conversationUsers, function (_, id) {
                return (0, _dependencies._get)(users, id, id);
            })
        });
    });

    if (searchFormValue) {
        return conversationsList.filter(function (conversation) {
            return isConversationMatchedByFilter(conversation, searchFormValue);
        });
    }

    return {
        conversations: conversationsList,
        isLoaded: isLoaded
    };
});

/**
 * Conversation & Messages
 */
var isConversationLoadedSelector = exports.isConversationLoadedSelector = (0, _dependencies.createSelector)(conversationIdFromPropsSelector, _dependencies.firebaseSelector, function (conversationId, firebase) {
    return !(0, _dependencies._get)(firebase, ['requesting', paths.conversationMessages(conversationId).id]);
});

var conversationSelector = exports.conversationSelector = (0, _dependencies.createSelector)(conversationIdFromPropsSelector, conversationsListSelector, function (conversationId, _ref5) {
    var conversations = _ref5.conversations;

    var conversation = conversations.find(function (c) {
        return c.conversationId === conversationId;
    });

    return {
        isEmpty: false,
        isLoaded: Boolean(conversation),
        conversation: _extends({}, conversation, {
            id: conversationId
        })
    };
});

var disabledPagingFromProps = function disabledPagingFromProps(_, _ref6) {
    var disabledPaging = _ref6.disabledPaging;
    return Boolean(disabledPaging);
};

var messagesCountsSelector = exports.messagesCountsSelector = (0, _dependencies.createSelector)(chatPagingSelector, conversationSelector, disabledPagingFromProps, function (paging, _ref7, disabledPaging) {
    var _ref7$conversation = _ref7.conversation,
        unseenMessagesCount = _ref7$conversation.unseenMessagesCount,
        messagesCount = _ref7$conversation.messagesCount;
    var page = paging.page,
        amount = paging.amount,
        sentMessages = paging.sentMessages;

    var count = disabledPaging ? Infinity : page * amount + sentMessages;

    return {
        count: unseenMessagesCount > count ? unseenMessagesCount : count,
        sentMessagesCount: sentMessages,
        unseenMessagesCount: unseenMessagesCount,
        messagesCount: messagesCount
    };
});

var messagesSelector = exports.messagesSelector = (0, _dependencies.createSelector)(userIdFromPropsSelector, conversationIdFromPropsSelector, _dependencies.firebaseSelector, isConversationLoadedSelector, function (state) {
    return state.chat.firstUnreadMessageId;
}, function (userId, conversationId, firebase, isLoaded, firstUnreadMessageId) {
    var messages = (0, _dependencies.populate)(firebase, paths.conversationMessages(conversationId).store, paths.populates.messages);

    var messagesWithId = (0, _dependencies._map)(messages, function (message, key) {
        return _extends({}, message, {
            messageId: key,
            seen: !(0, _dependencies._get)(message, ['unseen', userId], false),
            amIAuthor: (0, _dependencies._get)(message, 'author.authorId', '') === userId
        });
    });

    var firstUnreadMessageIndex = messagesWithId.findIndex(function (_ref8) {
        var messageId = _ref8.messageId;
        return messageId === firstUnreadMessageId;
    });
    var readMessagesCount = Math.max(firstUnreadMessageIndex, (0, _dependencies._isNil)(firstUnreadMessageId) ? messagesWithId.length : 0);

    return {
        isLoaded: isLoaded,
        isEmpty: messagesWithId.length === 0,
        messages: messagesWithId,
        readMessagesCount: readMessagesCount
    };
});

var unseenSelector = exports.unseenSelector = (0, _dependencies.createSelector)(userIdFromPropsSelector, conversationIdFromPropsSelector, _dependencies.firebaseSelector, function (userId, conversationId, firebase) {
    var users = (0, _dependencies._get)(firebase, 'data.' + paths.conversation(conversationId).store + '.users', {});

    return (0, _dependencies._omit)(users, userId);
});