'use strict';

require('babel-polyfill');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactRedux = require('react-redux');

var _reactIntl = require('react-intl');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _react3 = require('@storybook/react');

var _DataLoadDelay = require('./DataLoadDelay');

var _DataLoadDelay2 = _interopRequireDefault(_DataLoadDelay);

var _2 = require('../');

var _chatData = require('./chatData');

var _chat = require('./chat.envSetup');

require('./chatStories.scss');

require('../styles.scss');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Author = function Author(_ref) {
    var author = _ref.author,
        seen = _ref.seen;
    return _react2.default.createElement(
        'div',
        { className: (0, _classnames2.default)('author-circle', { 'author--unseen': !seen }) },
        _lodash2.default.get(author, 'name', '').split(' ').map(function (s) {
            return s.charAt(0);
        }).join('')
    );
};

Author.propTypes = {
    author: _propTypes2.default.shape({
        name: _propTypes2.default.string.isRequired
    }).isRequired,
    seen: _propTypes2.default.bool.isRequired
};

var Message = function Message(_ref2) {
    var text = _ref2.text,
        time = _ref2.time,
        seen = _ref2.seen,
        amIAuthor = _ref2.amIAuthor,
        author = _ref2.author;
    return _react2.default.createElement(
        'div',
        { style: { opacity: seen ? 0.5 : 1 }, className: 'custom-message' },
        _react2.default.createElement(
            'h4',
            null,
            ' ',
            amIAuthor ? 'ME' : _lodash2.default.get(author, 'name')
        ),
        _react2.default.createElement(
            'em',
            null,
            new Date(time).toString()
        ),
        _react2.default.createElement(
            'p',
            null,
            text
        )
    );
};

/* eslint-disable react/require-default-props,react/no-unused-prop-types */
Message.propTypes = {
    author: _propTypes2.default.shape({
        authorId: _propTypes2.default.string.isRequired,
        name: _propTypes2.default.string
    }),
    image: _propTypes2.default.string,
    text: _propTypes2.default.string,
    time: _propTypes2.default.number.isRequired,
    seen: _propTypes2.default.bool.isRequired,
    amIAuthor: _propTypes2.default.bool.isRequired,

    MessageAuthor: _propTypes2.default.func,
    MessageImage: _propTypes2.default.func,
    dateFormat: _propTypes2.default.string
};
/* eslint-enable react/require-default-props,react/no-unused-prop-types */

(0, _react3.storiesOf)('Modules|chat/Messages', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: _chat.store },
        _react2.default.createElement(
            _reactIntl.IntlProvider,
            { locale: 'en', messages: _chatData.intlMessages },
            _react2.default.createElement(
                'div',
                { className: 'panel messages-panel' },
                story()
            )
        )
    );
}).add('basic', function () {
    return _react2.default.createElement(_2.Messages, { conversationId: 'driver_1551', userId: 'dispatcher_9' });
}).add('no data', function () {
    return _react2.default.createElement(_2.Messages, { conversationId: 'driver_1553', userId: 'dispatcher_9' });
}).add('custom no data message', function () {
    return _react2.default.createElement(_2.Messages, {
        conversationId: 'driver_1553',
        userId: 'dispatcher_9',
        noDataMessage: _react2.default.createElement(
            'h3',
            { style: { textTransform: 'uppercase', textAlign: 'center' } },
            'Where are all my messges'
        )
    });
}).add('default loader', function () {
    return _react2.default.createElement(
        _DataLoadDelay2.default,
        { store: _chat.store, firebaseDataPath: 'messages/driver_1551' },
        _react2.default.createElement(_2.Messages, { conversationId: 'driver_1551', userId: 'dispatcher_9' })
    );
}).add('custom loader', function () {
    return _react2.default.createElement(
        _DataLoadDelay2.default,
        {
            store: _chat.store,
            firebaseDataPath: 'messages/driver_1551'
        },
        _react2.default.createElement(_2.Messages, {
            conversationId: 'driver_1551',
            userId: 'dispatcher_9',
            loader: _react2.default.createElement(
                'h3',
                { style: { color: 'blue', textAlign: 'center' } },
                'Loading messages with blue in heart'
            )
        })
    );
}).add('custom author', function () {
    return _react2.default.createElement(
        'div',
        { className: 'custom-author-messages' },
        _react2.default.createElement(_2.Messages, {
            conversationId: 'driver_1551',
            userId: 'dispatcher_9',
            MessageAuthor: Author
        })
    );
}).add('custom message', function () {
    return _react2.default.createElement(
        'div',
        { className: 'custom-author-messages' },
        _react2.default.createElement(_2.Messages, {
            conversationId: 'driver_1551',
            userId: 'dispatcher_9',
            MessageComponent: Message
        })
    );
}).add('disabled paging', function () {
    return _react2.default.createElement(
        'div',
        { className: 'custom-author-messages' },
        _react2.default.createElement(_2.Messages, {
            conversationId: 'driver_1554',
            userId: 'dispatcher_9',
            MessageComponent: Message,
            disabledPaging: true
        })
    );
});