import React from 'react';
import PropTypes from 'prop-types';

import { storiesOf } from '@storybook/react';

import loadable from '../../src/HOC/loadable';

const ContentComponent = () => (
    <h1 style={{ color: 'red' }}>Content component</h1>
);

const LoaderOverlay = ({ children, showLoader }) => (
    <div
        style={{
            position: 'absolute',
            top: 0,
            left: 0,
            right: 0,
            bottom: 0,
            backgroundColor: 'black',
            opacity: 0.7,
            display: showLoader ? 'block' : 'none',
        }}
    >
        {children}
    </div>
);

LoaderOverlay.propTypes = {
    showLoader: PropTypes.bool.isRequired,
    children: PropTypes.oneOfType([
        PropTypes.node,
        PropTypes.arrayOf(PropTypes.node),
    ]),
};

LoaderOverlay.defaultProps = {
    children: null,
};

const SimpleLoader = ({ children, show }) => (
    <div>
        {children}
        <LoaderOverlay showLoader={show} />
    </div>
);

SimpleLoader.propTypes = {
    children: LoaderOverlay.propTypes.children,
    show: PropTypes.bool,
};

SimpleLoader.defaultProps = {
    children: null,
    show: true,
};

const TextLoader = ({ children, text, show }) => (
    <div>
        {children}
        <LoaderOverlay showLoader={show}>
            <div style={{ color: 'red', marginTop: 150, textAlign: 'center' }}>
                {text}
            </div>
        </LoaderOverlay>
    </div>
);

TextLoader.propTypes = {
    text: PropTypes.string.isRequired,
    ...SimpleLoader.propTypes,
};

TextLoader.defaultProps = SimpleLoader.defaultProps;

class LiveLoader extends React.Component {
    state = { show: true, remaining: 5 };

    componentWillMount() {
        this.countdown();
    }

    countdown() {
        const nextRemaining = this.state.remaining - 1;
        this.setState({ remaining: nextRemaining });

        if (nextRemaining === 0) {
            this.setState({ show: false });
        } else {
            setTimeout(() => this.countdown(), nextRemaining * 1000);
        }
    }

    render() {
        const { remaining, show } = this.state;
        return (
            <TextLoader
                {...this.props}
                text={`${this.props.text} ${remaining}s`}
                show={show}
            />
        );
    }
}

LiveLoader.propTypes = TextLoader.propTypes;

storiesOf('HOC|Lodable', module)
    .add(
        'simple',
        () => {
            const LoadableComponent = loadable(SimpleLoader)(ContentComponent);
            return <LoadableComponent />;
        },
    )
    .add(
        'with text',
        () => {
            const LoadableComponent = loadable(TextLoader)(
                ContentComponent,
                'Loading content of my app..',
            );
            return <LoadableComponent />;
        },
    )
    .add(
        'using showLoader prop',
        () => {
            const LoadableComponent = loadable(LiveLoader)(
                ContentComponent,
                'Loading hide after few seconds',
            );
            return <LoadableComponent />;
        },
    );
